-
\ No newline at end of file
diff --git a/WebWindow.Base/Enums.cs b/WebWindow.Base/Enums.cs
new file mode 100644
index 0000000..0d653c4
--- /dev/null
+++ b/WebWindow.Base/Enums.cs
@@ -0,0 +1,46 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Text;
+using System.Threading.Tasks;
+
+namespace WebWindow.Base
+{
+ public class Enums
+ {
+ ///
+ /// Modo chiamata Engine
+ ///
+
+ public enum EngineQueryType
+ {
+ None = 0,
+ Preview,
+ Bom,
+ HardwareModelList
+ }
+
+ ///
+ /// SubMode di chiamata Engine
+ ///
+ public enum EngineSubMode
+ {
+ NULL = 0,
+ LIST = 1,
+ CALCSASH = 2,
+ SASHOPTIONS = 3
+ }
+
+
+ ///
+ /// Elenco produttori Hardware
+ ///
+ public enum EngineHwManufacturers
+ {
+ NULL = 0,
+ AGB = 1,
+ MAICO = 2,
+ ROTO = 3
+ }
+ }
+}
diff --git a/WebWindow.Base/WebWindow.Base.csproj b/WebWindow.Base/WebWindow.Base.csproj
index 3125f61..74a0418 100644
--- a/WebWindow.Base/WebWindow.Base.csproj
+++ b/WebWindow.Base/WebWindow.Base.csproj
@@ -6,7 +6,7 @@
net8.0
enable
enable
-
2.7.9.1313
+
2.7.9.1615
Annamaria Sassi
Egalware
Componente gestione JWD per LUX
@@ -23,3 +23,8 @@
+
+
+
+
+
diff --git a/WebWindowComplex/WebWindowComplex.csproj b/WebWindowComplex/WebWindowComplex.csproj
index 51fa38f..3f19654 100644
--- a/WebWindowComplex/WebWindowComplex.csproj
+++ b/WebWindowComplex/WebWindowComplex.csproj
@@ -6,7 +6,7 @@
net8.0
enable
enable
-
2.7.9.1313
+
2.7.9.1615
Annamaria Sassi
Egalware
Componente gestione Configurazioni avanzate Window per LUX
@@ -37,3 +37,8 @@
+
+
+
+
+
diff --git a/WebWindowConfigurator/WebWindowConfigurator.csproj b/WebWindowConfigurator/WebWindowConfigurator.csproj
index eb9269d..3e80884 100644
--- a/WebWindowConfigurator/WebWindowConfigurator.csproj
+++ b/WebWindowConfigurator/WebWindowConfigurator.csproj
@@ -6,7 +6,7 @@
net8.0
enable
enable
-
2.7.9.1313
+
2.7.9.1615
Annamaria Sassi
Egalware
Componente gestione JWD per LUX
@@ -48,3 +48,8 @@
+
+
+
+
+
diff --git a/WebAedificaConfigurator/WebAedificaMaker.razor.cs b/WebAedificaConfigurator/WebAedificaMaker.razor.cs
index 02c84bd..f69fb11 100644
--- a/WebAedificaConfigurator/WebAedificaMaker.razor.cs
+++ b/WebAedificaConfigurator/WebAedificaMaker.razor.cs
@@ -8,6 +8,7 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Xml;
+using WebWindow.Base;
namespace WebAedificaConfigurator
{
@@ -54,15 +55,15 @@ namespace WebAedificaConfigurator
// leggo il contenuto del PRIMO (singolo) file
IBrowserFile file = e.File;
- // limite file size (e.g., 5 MB)
- var maxAllowedSize = 1024 * 1024;
+ // limite file size (al momento 10 MB)
+ var maxAllowedSize = 10* 1024 * 1024;
using var stream = file.OpenReadStream(maxAllowedSize);
using var reader = new StreamReader(stream);
string rawContent = await reader.ReadToEndAsync();
+ // parametri richiesta
+ Args.Add("Mode", $"{(int)Enums.EngineQueryType.Preview}");
Args.Add("Btl", rawContent);
- // da sostituire con Enums.EngineQueryType.Preview
- Args.Add("Mode", "1");
await EC_OnSave.InvokeAsync(Args);
}